@@ -32,7 +32,7 @@
 package GD::Graph;
 
 ($GD::Graph::prog_version) = '$Revision: 1.55 $' =~ /\s([\d.]+)/;
-$GD::Graph::VERSION = '1.53';
+$GD::Graph::VERSION = '1.54';
 
 use strict;
 use GD;
@@ -1191,10 +1191,7 @@ Default: 0.
 
 =item y_max_value, y_min_value
 
-Maximum and minimum value displayed on the y axis. If two_axes is a
-true value, then y1_min_value, y1_max_value (for the left axis),
-and y2_min_value, y2_max_value (for the right axis) take precedence
-over these.
+Maximum and minimum value displayed on the y axis.
 
 The range (y_min_value..y_max_value) has to include all the values of
 the data points, or I<GD::Graph> will die with a message.
@@ -1205,6 +1202,17 @@ to draw the graph.
 
 Default: Computed from data sets.
 
+=item y1_max_value, y1_min_value, y2_max_value, y2_min_value
+
+Maximum and minimum values for left (y1) and right (y2) axes when
+B<two_axes> is a true value. Take precedence over y_min_value
+and y_max_value.
+
+By default 0 of the left axis is aligned with 0 of the right axis,
+it's not true if any of these options is defined.
+
+Otherwise behaviour and default values are as with y_max_value and y_min_value.
+
 =item y_min_range, y1_min_range, y2_min_range
 
 Minimal range between min and max values on y axis that is used to adjust
